summary refs log tree commit diff stats
path: root/tests/errmsgs/tsigmatch.nim
diff options
context:
space:
mode:
authorflywind <xzsflywind@gmail.com>2022-01-04 20:29:50 +0800
committerGitHub <noreply@github.com>2022-01-04 13:29:50 +0100
commit9df195ef581879cf9e5c3c3154755bd1dba677c6 (patch)
tree71dc955a6976558b3cb47f98443093b388c1ce36 /tests/errmsgs/tsigmatch.nim
parent1869826668e2e3a0fd69cc1b69fb12b07993e417 (diff)
downloadNim-9df195ef581879cf9e5c3c3154755bd1dba677c6.tar.gz
style usages part one (openarray => openArray) (#19321)
* style usages (openArray)

* revert doc changes
Diffstat (limited to 'tests/errmsgs/tsigmatch.nim')
-rw-r--r--tests/errmsgs/tsigmatch.nim4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/errmsgs/tsigmatch.nim b/tests/errmsgs/tsigmatch.nim
index 023b7d518..8f32ef9e6 100644
--- a/tests/errmsgs/tsigmatch.nim
+++ b/tests/errmsgs/tsigmatch.nim
@@ -132,12 +132,12 @@ block:
   echo foo(fun)
 
 block:
   # bug #10285 Function signature don't match when inside seq/array/openarray
   # Note: the error message now shows `closure` which helps debugging the issue
   # out why it doesn't match
   proc takesFunc(f: proc (x: int) {.gcsafe, locks: 0.}) =
     echo "takes single Func"
-  proc takesFuncs(fs: openarray[proc (x: int) {.gcsafe, locks: 0.}]) =
+  proc takesFuncs(fs: openArray[proc (x: int) {.gcsafe, locks: 0.}]) =
     echo "takes multiple Func"
   takesFunc(proc (x: int) {.gcsafe, locks: 0.} = echo x)         # works
   takesFuncs([proc (x: int) {.gcsafe, locks: 0.} = echo x])      # fails
@@ -132,12 +132,12 @@ block:
 
 block:
-  # bug #10285 Function signature don't match when inside seq/array/openarray
+  # bug #10285 Function signature don't match when inside seq/array/openArray
   # Note: the error message now shows `closure` which helps debugging the issue
   # out why it doesn't match